Cabby — Cabby 0.1.5 documentation

### Navigation

- index
- modules |
- next |
- Cabby 0.1.5 documentation »

# Cabby

Cabby is Python TAXII client implementation from Intelworks.

TAXII (Trusted Automated eXchange of Indicator Information) is a collection of specifications defining a set of services and message exchanges used for sharing cyber threat intelligence information between parties. Check TAXII homepage to get more information.

Cabby is designed from the ground up to act as a Python library and as a command line tool, it’s key features are:

- Rich feature set: it supports all TAXII services according to TAXII specification (v1.0 and v1.1).
- Version agnostic: it abstracts specific implementation details and returns version agnostic entities.

Documentation contents

- Installation guide
- User guide
- Cabby API documentation
- Contributing and developing
- Changelog for cabby
- License

External links

- Online documentation (Read the docs)
- Project page with source code and issue tracker (Github)
- Python Package Index (PyPI) page with released tarballs

### Navigation

- index
- modules |
- next |
- Cabby 0.1.5 documentation »